===============
sxip_drivers.py
===============

Sxip class
==========
.. autoclass:: sxip.Sxip
    :members:
    :undoc-members:
    :show-inheritance:
    :member-order: bysource

Exceptions
==========

Exceptions inherited from phox-modbus
-------------------------------------
.. autoclass:: modbus.ModbusError
.. autoclass:: modbus.SlaveExceptionError
.. autoclass:: modbus.IllegalRequestError
.. autoclass:: modbus.MasterReportedError
.. autoclass:: modbus.NoResponseError
.. autoclass:: modbus.InvalidResponseError

Exceptions inherited from pyserial
----------------------------------
.. autoclass:: serial.SerialException
.. autoclass:: serial.PortNotOpenError
.. autoclass:: serial.SerialTimeoutException